==> haskell-torrent-10000.1.3-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 torrent
version:              10000.1.3
visibility:           public
id:                   torrent-10000.1.3-97j7r4YMa9M1u4P2qWM8Er
key:                  torrent-10000.1.3-97j7r4YMa9M1u4P2qWM8Er
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  d21f446399a2c556d98ba2c3788361e0
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-torrent
hs-libraries:         HStorrent-10000.1.3-97j7r4YMa9M1u4P2qWM8Er
depends:
    base-4.17.2.1 bencode-0.6.1.1-8VmkbsWIEf03KEMq7n1hjp binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.2.2
    syb-0.7.3-8wamvTeFqIS3IMzaHn3GXS

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-torrent-10000.1.3-115-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-torrent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 torrent
version:              10000.1.3
visibility:           public
id:                   torrent-10000.1.3-AtZDDQMvv8I9ecWEaE9MRs
key:                  torrent-10000.1.3-AtZDDQMvv8I9ecWEaE9MRs
license:              BSD-3-Clause
copyright:            2005-2007, Lemmih
maintainer:           Joey Hess <id@joeyh.name>
author:               Lemmih <lemmih@gmail.com>
synopsis:             BitTorrent file parser and generater
category:             Network
abi:                  96bcb8c4dc61662d56386a34fb4f36e1
exposed:              True
exposed-modules:      Data.Torrent Data.Torrent.Scrape
import-dirs:          /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/torrent-10000.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-torrent
hs-libraries:         HStorrent-10000.1.3-AtZDDQMvv8I9ecWEaE9MRs
depends:
    base-4.17.2.1 bencode-0.6.1.1-IBWkkxFF8kM5PNBSi9fual binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7 filepath-1.4.2.2
    syb-0.7.3-GR8SQUvypud7ZjWJ9MTjse

haddock-interfaces:   /usr/share/doc/haskell-torrent/html/torrent.haddock
haddock-html:         /usr/share/doc/haskell-torrent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
